==> haskell-torrent-10000.1.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: torrent
version: 10000.1.1
id: torrent-10000.1.1-KopeGy7uN5q8jcrTmCxCCS
key: torrent-10000.1.1-KopeGy7uN5q8jcrTmCxCCS
license: BSD3
copyright: 2005-2007, Lemmih
maintainer: Joey Hess <id@joeyh.name>
synopsis: BitTorrent file parser and generater
category: Network
author: Lemmih <lemmih@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Torrent Data.Torrent.Scrape
abi: e036440b33e96f0436ef21e75c82fb61
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/torrent-10000.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/torrent-10000.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/torrent-10000.1.1
hs-libraries: HStorrent-10000.1.1-KopeGy7uN5q8jcrTmCxCCS
depends:
    base-4.10.1.0 bencode-0.6.0.0-Jw8er8rrhuMEfRxBrsU6mL binary-0.8.5.1
    bytestring-0.10.8.2 containers-0.5.10.2 filepath-1.4.1.2
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bencode-0.6.0.0-Jw8er8rrhuMEfRxBrsU6mL=a7a294f57233fa232a04ea988e4cf470
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=06df45b1c27c5cef935930b2f87d2689
haddock-interfaces: /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html: /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-torrent-10000.1.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: torrent
version: 10000.1.1
id: torrent-10000.1.1-6AyKVjYwg8rAPSsycwJwZt
key: torrent-10000.1.1-6AyKVjYwg8rAPSsycwJwZt
license: BSD3
copyright: 2005-2007, Lemmih
maintainer: Joey Hess <id@joeyh.name>
synopsis: BitTorrent file parser and generater
category: Network
author: Lemmih <lemmih@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Torrent Data.Torrent.Scrape
abi: e532ced3930f89e869dbf634f1d84ed6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/torrent-10000.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/torrent-10000.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/torrent-10000.1.1
hs-libraries: HStorrent-10000.1.1-6AyKVjYwg8rAPSsycwJwZt
depends:
    base-4.10.1.0 bencode-0.6.0.0-9RVBdVFaR6cFoQMfedrmHg binary-0.8.5.1
    bytestring-0.10.8.2 containers-0.5.10.2 filepath-1.4.1.2
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bencode-0.6.0.0-9RVBdVFaR6cFoQMfedrmHg=9e7724baec98d7cb8ebd78deefc24fdf
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=06df45b1c27c5cef935930b2f87d2689
haddock-interfaces: /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html: /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
